@@ -1,6 +1,6 @@
 from PyPDF2 import PdfWriter, PdfReader
 
-def remove_pages(input_file_path, *pages, out_file_path):
+def remove_pages(input_file_path, pages, out_file_path):
     pages_to_keep = pages # page numbering starts from 0
     infile = PdfReader(input_file_path, 'rb')
     output = PdfWriter()
